@@ -2,7 +2,7 @@
  Project: Graphos
  GRBezierPath.h
 
- Copyright (C) 2000-2010 GNUstep Application Project
+ Copyright (C) 2000-2011 GNUstep Application Project
 
  Author: Enrico Sersale (original implementation)
  Author: Ing. Riccardo Mottola
@@ -37,14 +37,14 @@ typedef struct
 
 @interface GRBezierPath : GRPathObject
 {
-    float flatness, miterlimit;
-    int linejoin, linecap;
     BOOL calculatingHandles;
     NSMutableArray *controlPoints;
 }
 
 - (id)initInView:(GRDocView *)aView zoomFactor:(float)zf;
-
+- (id)initInView:(GRDocView *)aView
+      zoomFactor:(float)zf
+      withProperties:(NSDictionary *)properties;
 - (id)initFromData:(NSDictionary *)description
             inView:(GRDocView *)aView
         zoomFactor:(float)zf;
@@ -61,17 +61,6 @@ typedef struct
 - (GRBezierControlPoint *)pointOnPoint:(GRBezierControlPoint *)aPoint;
 - (void)confirmNewCurve;
 
-- (void)setFlat:(float)flat;
-- (float)flatness;
-- (void)setLineJoin:(int)join;
-- (int)lineJoin;
-- (void)setLineCap:(int)cap;
-- (int)lineCap;
-- (void)setMiterLimit:(float)limit;
-- (float)miterLimit;
-- (void)setLineWidth:(float)width;
-- (float)lineWidth;
-
 - (void)unselectOtherControls:(GRBezierControlPoint *)cp;
 
 
