@@ -2,7 +2,7 @@
  Project: Graphos
  GRBezierPath.m
 
- Copyright (C) 2000-2010 GNUstep Application Project
+ Copyright (C) 2000-2011 GNUstep Application Project
 
  Author: Enrico Sersale (original GDraw implementation)
  Author: Ing. Riccardo Mottola
@@ -57,6 +57,55 @@ static double k = 0.025;
     return self;
 }
 
+/** initializes by using the properties array as defaults */
+- (id)initInView:(GRDocView *)aView
+      zoomFactor:(float)zf
+      withProperties:(NSDictionary *)properties
+{
+  self = [self initInView:aView zoomFactor:zf];
+  if(self)
+    {
+      NSColor *newColor;
+      NSString *val;
+
+      val = [properties objectForKey: @"flatness"];
+      if (val != nil)
+	[self setFlat: [val floatValue]];
+
+      val = [properties objectForKey: @"linejoin"];
+      if (val != nil)
+	[self setLineJoin: [val intValue]];
+
+      val = [properties objectForKey: @"linecap"];
+      if (val != nil)
+	[self setLineCap: [val intValue]];
+
+      val = [properties objectForKey: @"miterlimit"];
+      if (val != nil)
+	[self setMiterLimit: [val floatValue]];
+
+      val = [properties objectForKey: @"linewidth"];
+      if (val != nil)
+      [self setLineWidth: [val floatValue]];
+
+      val = [properties objectForKey: @"stroked"];
+      if (val != nil)
+	[self setStroked: (BOOL)[val intValue]];
+      newColor = (NSColor *)[properties objectForKey: @"strokecolor"];
+      if (newColor != nil)
+	[self setStrokeColor: newColor];
+
+      val = [properties objectForKey: @"filled"];
+      if (val != nil)
+	[self setFilled: (BOOL)[val intValue]];
+      newColor = (NSColor *)[properties objectForKey: @"fillcolor"];
+      if (newColor != nil)
+	[self setFillColor: newColor];
+    }
+
+  return self;
+}
+
 - (id)initFromData:(NSDictionary *)description
         inView:(GRDocView *)aView
         zoomFactor:(float)zf
@@ -401,7 +450,6 @@ static double k = 0.025;
     int i, pcount, index;
     double y, s, ax, ay;
 
-//    printf("%s\n", [[self psDescription] cString]);
     return;
     // #### FIXME what the crap is this? we always return... the rest of the method is useless!!!
     pcount = 0;
@@ -667,55 +715,6 @@ static double k = 0.025;
 }
 
 
-- (void)setFlat:(float)flat
-{
-    flatness = flat;
-}
-
-- (float)flatness
-{
-    return flatness;
-}
-
-- (void)setLineJoin:(int)join
-{
-    linejoin = join;
-}
-
-- (int)lineJoin
-{
-    return linejoin;
-}
-
-- (void)setLineCap:(int)cap
-{
-    linecap = cap;
-}
-
-- (int)lineCap
-{
-    return linecap;
-}
-
-- (void)setMiterLimit:(float)limit
-{
-    miterlimit = limit;
-}
-
-- (float)miterLimit
-{
-    return miterlimit;
-}
-
-- (void)setLineWidth:(float)width
-{
-    linewidth = width;
-}
-
-- (float)lineWidth
-{
-    return linewidth;
-}
 
 
 /* override for editor handling */
