@@ -2,7 +2,7 @@
  Project: Graphos
  GRCircle.h
 
- Copyright (C) 2009-2010 GNUstep Application Project
+ Copyright (C) 2009-2011 GNUstep Application Project
 
  Author: Ing. Riccardo Mottola
 
@@ -37,12 +37,13 @@
     GRObjectControlPoint *startControlPoint;
     GRObjectControlPoint *endControlPoint;
     float rotation;
-    float flatness, miterlimit;
-    int linejoin, linecap;    
 }
 
 - (id)initInView:(GRDocView *)aView
       zoomFactor:(float)zf;
+- (id)initInView:(GRDocView *)aView
+      zoomFactor:(float)zf
+      withProperties:(NSDictionary *)properties;
 - (BOOL)onControlPoint:(NSPoint)p;
 - (void)setStartAtPoint:(NSPoint)aPoint;
 - (void)setEndAtPoint:(NSPoint)aPoint;
