@@ -2,7 +2,7 @@
  Project: Graphos
  GRCircle.m
 
- Copyright (C) 2009-2010 GNUstep Application Project
+ Copyright (C) 2009-2011 GNUstep Application Project
 
  Author: Ing. Riccardo Mottola
 
@@ -66,6 +66,55 @@
     return self;
 }
 
+/** initializes by using the properties array as defaults */
+- (id)initInView:(GRDocView *)aView
+      zoomFactor:(float)zf
+      withProperties:(NSDictionary *)properties
+{
+  self = [self initInView:aView zoomFactor:zf];
+  if(self)
+    {
+      NSColor *newColor;
+      NSString *val;
+
+      val = [properties objectForKey: @"flatness"];
+      if (val != nil)
+	[self setFlat: [val floatValue]];
+
+      val = [properties objectForKey: @"linejoin"];
+      if (val != nil)
+	[self setLineJoin: [val intValue]];
+
+      val = [properties objectForKey: @"linecap"];
+      if (val != nil)
+	[self setLineCap: [val intValue]];
+
+      val = [properties objectForKey: @"miterlimit"];
+      if (val != nil)
+	[self setMiterLimit: [val floatValue]];
+
+      val = [properties objectForKey: @"linewidth"];
+      if (val != nil)
+      [self setLineWidth: [val floatValue]];
+
+      val = [properties objectForKey: @"stroked"];
+      if (val != nil)
+	[self setStroked: (BOOL)[val intValue]];
+      newColor = (NSColor *)[properties objectForKey: @"strokecolor"];
+      if (newColor != nil)
+	[self setStrokeColor: newColor];
+
+      val = [properties objectForKey: @"filled"];
+      if (val != nil)
+	[self setFilled: (BOOL)[val intValue]];
+      newColor = (NSColor *)[properties objectForKey: @"fillcolor"];
+      if (newColor != nil)
+	[self setFillColor: newColor];
+    }
+
+  return self;
+}
+
 /** initializes all parameters from a description dictionary */
 - (id)initFromData:(NSDictionary *)description
             inView:(GRDocView *)aView
@@ -250,56 +299,6 @@
     [(GRCircleEditor *)editor setIsDone:YES];
 }
 
-- (void)setFlat:(float)flat
-{
-    flatness = flat;
-}
-
-- (float)flatness
-{
-    return flatness;
-}
-
-- (void)setLineJoin:(int)join
-{
-    linejoin = join;
-}
-
-- (int)lineJoin
-{
-    return linejoin;
-}
-
-- (void)setLineCap:(int)cap
-{
-    linecap = cap;
-}
-
-- (int)lineCap
-{
-    return linecap;
-}
-
-- (void)setMiterLimit:(float)limit
-{
-    miterlimit = limit;
-}
-
-- (float)miterLimit
-{
-    return miterlimit;
-}
-
-- (void)setLineWidth:(float)width
-{
-    linewidth = width;
-}
-
-- (float)lineWidth
-{
-    return linewidth;
-}
-
 
 - (void)setLocked:(BOOL)value
 {
@@ -372,7 +371,7 @@
 
     center = NSMakePoint(NSMidX(bounds), NSMidY(bounds));
     w = NSWidth(bounds);
-    h = NSWidth(bounds);
+    h = NSHeight(bounds);
     if (w > h)
         minLength = h;
     else
