@@ -2,7 +2,7 @@
  Project: Graphos
  GRDocView.h
 
- Copyright (C) 2000-2010 GNUstep Application Project
+ Copyright (C) 2000-2011 GNUstep Application Project
 
  Author: Enrico Sersale (original GDraw implementation)
  Author: Ing. Riccardo Mottola
@@ -108,7 +108,9 @@
 - (BOOL)moveControlPointOfEditor:(GRPathEditor *)editor toPoint:(NSPoint)pos;
 - (BOOL)moveBezierHandleOfEditor:(GRBezierPathEditor *)editor toPoint:(NSPoint)pos;
 - (void)subdividePathAtPoint:(NSPoint)p splitIt:(BOOL)split;
-- (IBAction)inspectObject: (id)sender;
+
+- (NSDictionary *)selectionProperties;
+- (void)setSelectionProperties: (NSDictionary *)properties;
 
 - (IBAction)moveSelectedObjectsToFront:(id)sender;
 - (IBAction)moveSelectedObjectsToBack:(id)sender;
