@@ -1,9 +1,8 @@
-
 /*
  Project: Graphos
  GRDocView.m
 
- Copyright (C) 2000-2010 GNUstep Application Project
+ Copyright (C) 2000-2012 GNUstep Application Project
 
  Author: Enrico Sersale (original GDraw implementation)
  Author: Ing. Riccardo Mottola
@@ -35,6 +34,7 @@
 #import "GRCircleEditor.h"
 #import "GRPropsEditor.h"
 
+#define UNDO_ACTION_OBJPROPS @"Change Object Properties"
 
 float zFactors[9] = {0.25, 0.5, 1, 1.5, 2, 3, 4, 6, 8};
 
@@ -85,42 +85,52 @@ float zFactors[9] = {0.25, 0.5, 1, 1.5, 2, 3, 4, 6, 8};
 
 - (NSDictionary *) objectDictionary
 {
-    NSMutableDictionary *objsdict;
-    NSString *str = nil;
-    id obj;
-    int i;
-    int p = 0;
-    int c = 0;
-    int t = 0;
-    int b = 0;
-
-    objsdict = [NSMutableDictionary dictionaryWithCapacity: 1];
-    for(i = 0; i < [objects count]; i++)
+  NSMutableDictionary *objsdict;
+  NSMutableArray *objectOrder;
+  NSString *str = nil;
+  id obj;
+  int i;
+  int p = 0;
+  int c = 0;
+  int t = 0;
+  int b = 0;
+  
+  objsdict = [NSMutableDictionary dictionaryWithCapacity: 1];
+  objectOrder = [NSMutableArray arrayWithCapacity: [objects count]];
+  for(i = 0; i < [objects count]; i++)
     {
-        obj = [objects objectAtIndex: i];
-        if([obj isKindOfClass: [GRBezierPath class]])
+      obj = [objects objectAtIndex: i];
+      NSLog(@"class: %@", [obj className]);
+      if([obj isKindOfClass: [GRBezierPath class]])
         {
-            str = [NSString stringWithFormat: @"path%i", p];
-            p++;
-        } else if([obj isKindOfClass: [GRBox class]])
+	  str = [NSString stringWithFormat: @"path%i", p];
+	  p++;
+        }
+      else if([obj isKindOfClass: [GRBox class]])
         {
-            str = [NSString stringWithFormat: @"box%i", b];
-            b++;
-        } else if([obj isKindOfClass: [GRCircle class]])
+	  str = [NSString stringWithFormat: @"box%i", b];
+	  b++;
+        }
+      else if([obj isKindOfClass: [GRCircle class]])
         {
-            str = [NSString stringWithFormat: @"circle%i", c];
-            c++;
-        } else if([obj isKindOfClass: [GRText class]])
+	  str = [NSString stringWithFormat: @"circle%i", c];
+	  c++;
+        }
+      else if([obj isKindOfClass: [GRText class]])
         {
-            str = [NSString stringWithFormat: @"text%i", t];
-            t++;
-        } else
-	    {
-	       [NSException raise:@"Unhandled object type" format:@"%@", [obj class]];
-	    }
-        [objsdict setObject: [obj objectDescription] forKey: str];
+	  str = [NSString stringWithFormat: @"text%i", t];
+	  t++;
+        }
+      else
+	{
+	  [NSException raise:@"Unhandled object type" format:@"%@", [obj class]];
+	}
+      [objectOrder addObject: str];
+      [objsdict setObject: [obj objectDescription] forKey: str];
     }
-    return [NSDictionary dictionaryWithDictionary: objsdict];
+  [objsdict setValue:[NSNumber numberWithFloat:FILE_FORMAT_VERSION] forKey:@"Version"];
+  [objsdict setValue:objectOrder forKey:@"Order"];
+  return [NSDictionary dictionaryWithDictionary: objsdict];
 }
 
 
@@ -166,118 +176,207 @@ float zFactors[9] = {0.25, 0.5, 1, 1.5, 2, 3, 4, 6, 8};
     GRBox *box;
     GRCircle *circle;
     int i;
+    float version;
+    NSNumber *versionNumber;
 
     if(!dict)
-        return NO;
+      return NO;
 
-    keys = [dict allKeys];
-    for(i = 0; i < [keys count]; i++)
-    {
-        key = [keys objectAtIndex: i];
-        objdict = [dict objectForKey: key];
-        if(!objdict)
-            return NO;
+    version = 0.0;
+    versionNumber = [dict objectForKey:@"Version"];
+    if (versionNumber)
+      version = [versionNumber floatValue];
+    NSLog(@"loading file of version: %f", version);
 
-        if([key rangeOfString: @"path"].length)
-        {
-            bzPath = [[GRBezierPath alloc] initFromData: objdict
-                                                 inView: self zoomFactor: zFactor];
-            [objects addObject: bzPath];
-            [bzPath release];
-            edind = [objects count] -1;
-        } else if([key rangeOfString: @"text"].length)
-        {
-            gGRText = [[GRText alloc] initFromData: objdict
-                                            inView: self zoomFactor: zFactor];
-            [objects addObject: gGRText];
-            [gGRText release];
-        } else if([key rangeOfString: @"box"].length)
-        {
-            box = [[GRBox alloc] initFromData: objdict
-                                            inView: self zoomFactor: zFactor];
-            [objects addObject: box];
-            [box release];
-        } else if([key rangeOfString: @"circle"].length)
-        {
-            circle = [[GRCircle alloc] initFromData: objdict
-                                       inView: self zoomFactor: zFactor];
-            [objects addObject: circle];
-            [circle release];
-        } else
-        {
-	       [NSException raise:@"Unsupported object in file." format:@"Key: %@", key]; 
-        }
-    }
+    if (version < 0.3)
+      {
+	/* loading for files without ordering */
+
+	NSLog(@"Loading old file version, < 0.3");
+	keys = [dict allKeys];
+	for(i = 0; i < [keys count]; i++)
+	  {
+	    key = [keys objectAtIndex: i];
+	    objdict = [dict objectForKey: key];
+	    if(!objdict)
+	      return NO;
+
+	    if([key rangeOfString: @"path"].length)
+	      {
+		bzPath = [[GRBezierPath alloc] initFromData: objdict
+						     inView: self zoomFactor: zFactor];
+		[objects addObject: bzPath];
+		[bzPath release];
+		edind = [objects count] -1;
+	      }
+	    else if([key rangeOfString: @"text"].length)
+	      {
+		gGRText = [[GRText alloc] initFromData: objdict
+						inView: self zoomFactor: zFactor];
+		[objects addObject: gGRText];
+		[gGRText release];
+	      }
+	    else if([key rangeOfString: @"box"].length)
+	      {
+		box = [[GRBox alloc] initFromData: objdict
+					   inView: self zoomFactor: zFactor];
+		[objects addObject: box];
+		[box release];
+	      }
+	    else if([key rangeOfString: @"circle"].length)
+	      {
+		circle = [[GRCircle alloc] initFromData: objdict
+						 inView: self zoomFactor: zFactor];
+		[objects addObject: circle];
+		[circle release];
+	      }
+	    else if ([key isEqualToString:@"Version"])
+	      {
+		/* skip, already parsed */
+	      }
+	    else
+	      {
+		[NSException raise:@"Unsupported object in file." format:@"Key: %@", key]; 
+	      }
+	  }
+      } 
+    else
+      {
+	/* loading of files with encoded ordering */
+	NSArray *order;
+
+	NSLog(@"Loading version 0.3 or later, ordered objects");
+	order = [dict objectForKey:@"Order"];
+	for(i = 0; i < [order count]; i++)
+	  {
+	    key = [order objectAtIndex: i];
+	    objdict = [dict objectForKey: key];
+	    if(!objdict)
+	      return NO;
+
+	    if([key rangeOfString: @"path"].length)
+	      {
+		bzPath = [[GRBezierPath alloc] initFromData: objdict
+						     inView: self zoomFactor: zFactor];
+		[objects addObject: bzPath];
+		[bzPath release];
+		edind = [objects count] -1;
+	      }
+	    else if([key rangeOfString: @"text"].length)
+	      {
+		gGRText = [[GRText alloc] initFromData: objdict
+						inView: self zoomFactor: zFactor];
+		[objects addObject: gGRText];
+		[gGRText release];
+	      }
+	    else if([key rangeOfString: @"box"].length)
+	      {
+		box = [[GRBox alloc] initFromData: objdict
+					   inView: self zoomFactor: zFactor];
+		[objects addObject: box];
+		[box release];
+	      }
+	    else if([key rangeOfString: @"circle"].length)
+	      {
+		circle = [[GRCircle alloc] initFromData: objdict
+						 inView: self zoomFactor: zFactor];
+		[objects addObject: circle];
+		[circle release];
+	      }
+	    else
+	      {
+		[NSException raise:@"Unsupported object in file." format:@"Key: %@", key]; 
+	      }
+	  }
+      }
     return YES;
 }
 
 - (void)addPath
 {
-    GRBezierPath *path;
+  GRBezierPath *path;
+  GRPropsEditor *objInspector;
 
-    path = [[GRBezierPath alloc] initInView: self zoomFactor: zFactor];
-    [objects addObject: path];
-    [path release];
-    edind = [objects count] -1;
+  objInspector = [[[NSApplication sharedApplication] delegate] objectInspector];
+
+  path = [[GRBezierPath alloc] initInView: self
+			       zoomFactor: zFactor
+			   withProperties: [objInspector properties]];
+
+  [objects addObject: path];
+  [path release];
+  edind = [objects count] -1;
+  [[NSNotificationCenter defaultCenter] postNotificationName:@"ObjectSelectionChanged" object:self];
 }
 
 - (void)addTextAtPoint:(NSPoint)p
 {
-    GRText *gdtxt;
-    int i;
-    NSUndoManager *uMgr;
-    
-    uMgr = [self undoManager];
-    /* save the method on the undo stack */
-    [[uMgr prepareWithInvocationTarget: self] restoreLastObjects];
-    [uMgr setActionName:@"Add Text"];
-    
-    [self saveCurrentObjects];
-    
-    NSLog(@"AddTextAtPoint");
-    for(i = 0; i < [objects count]; i++)
-        [[[objects objectAtIndex: i] editor] unselect];
+  GRText *gdtxt;
+  int i;
+  NSUndoManager *uMgr;
+  GRPropsEditor *objInspector;
 
-    gdtxt = [[GRText alloc] initInView: self atPoint: p
-                            zoomFactor: zFactor openEditor: YES];
-    [objects addObject: gdtxt];
-    [[gdtxt editor] select];
-    [gdtxt release];
-    [self setNeedsDisplay: YES];
+  objInspector = [[[NSApplication sharedApplication] delegate] objectInspector];
+    
+  uMgr = [self undoManager];
+  /* save the method on the undo stack */
+  [[uMgr prepareWithInvocationTarget: self] restoreLastObjects];
+  [uMgr setActionName:@"Add Text"];
+    
+  [self saveCurrentObjects];
+    
+  NSLog(@"AddTextAtPoint");
+  for(i = 0; i < [objects count]; i++)
+    [[[objects objectAtIndex: i] editor] unselect];
+
+  gdtxt = [[GRText alloc] initInView: self
+			     atPoint: p
+			  zoomFactor: zFactor
+		      withProperties: [objInspector properties]
+			  openEditor: YES];
+  [objects addObject: gdtxt];
+  [[gdtxt editor] select];
+  [gdtxt release];
+  [self setNeedsDisplay: YES];
+  [[NSNotificationCenter defaultCenter] postNotificationName:@"ObjectSelectionChanged" object:self];
 }
 
 - (void)addBox
 {
-    GRBox *box;
-    
-//    for(i = 0; i < [objects count]; i++)
-//        [[[objects objectAtIndex: i] editor] unselect];
+  GRBox *box;
+  GRPropsEditor *objInspector;
 
-    box = [[GRBox alloc] initInView: self  
-                            zoomFactor: zFactor];
+  objInspector = [[[NSApplication sharedApplication] delegate] objectInspector];
 
-    [objects addObject: box];
-    [[box editor] select];
-    [box release];
-    [self setNeedsDisplay: YES];
-    edind = [objects count] -1;
+  box = [[GRBox alloc] initInView: self
+		       zoomFactor: zFactor
+		   withProperties: [objInspector properties]];
+
+  [objects addObject: box];
+  [[box editor] select];
+  [box release];
+  [self setNeedsDisplay: YES];
+  edind = [objects count] -1;
+  [[NSNotificationCenter defaultCenter] postNotificationName:@"ObjectSelectionChanged" object:self];
 }
 
 - (void)addCircle
 {
-    GRCircle *circle;
+  GRCircle *circle;
+  GRPropsEditor *objInspector;
 
-    //    for(i = 0; i < [objects count]; i++)
-    //        [[[objects objectAtIndex: i] editor] unselect];
+  objInspector = [[[NSApplication sharedApplication] delegate] objectInspector];
 
-    circle = [[GRCircle alloc] initInView: self
-                         zoomFactor: zFactor];
+  circle = [[GRCircle alloc] initInView: self
+			     zoomFactor: zFactor
+			 withProperties: [objInspector properties]];
 
-    [objects addObject: circle];
-    [[circle editor] select];
-    [circle release];
-    [self setNeedsDisplay: YES];
-    edind = [objects count] -1;
+  [objects addObject: circle];
+  [[circle editor] select];
+  [circle release];
+  [self setNeedsDisplay: YES];
+  [[NSNotificationCenter defaultCenter] postNotificationName:@"ObjectSelectionChanged" object:self];
+  edind = [objects count] -1;
 }
 
 - (NSArray *)duplicateObjects:(NSArray *)objs andMoveTo:(NSPoint)p
@@ -307,21 +406,32 @@ float zFactors[9] = {0.25, 0.5, 1, 1.5, 2, 3, 4, 6, 8};
 
 - (void)updatePrintInfo: (NSPrintInfo *)pi;
 {
-    float lm, rm;
+  float lm, rm;
+
+  if (pi == nil)
+    {
+      NSLog(@"invalid printer information");
+      return;
+    }
+  lm = [pi leftMargin];
+  rm = [pi rightMargin];
+  if (lm <= 0 || rm <= 0 || [pi paperSize].width <= 0 || [pi paperSize].height <= 0)
+    {
+      NSLog(@"invalid margin / paper size information. %f %f %f %f", lm, rm,[pi paperSize].width, [pi paperSize].height);
+      return;
+    }
+  pageRect = NSMakeRect(0,0,[pi paperSize].width, [pi paperSize].height);
+
+  a4Rect = NSMakeRect([pi leftMargin], [pi bottomMargin],
+		      pageRect.size.width-([pi leftMargin]+[pi rightMargin]),
+		      pageRect.size.height-([pi topMargin]+[pi bottomMargin]));
     
-    lm = [pi leftMargin];
-    rm = [pi rightMargin];
-    pageRect = NSMakeRect(0,0,[pi paperSize].width, [pi paperSize].height);
-    a4Rect = NSMakeRect([pi leftMargin], [pi bottomMargin],
-             pageRect.size.width-([pi leftMargin]+[pi rightMargin]),
-             pageRect.size.height-([pi topMargin]+[pi bottomMargin]));
-    
-    zmdRect = a4Rect;
-    zIndex = 2;
-    zFactor = zFactors[zIndex];
+  zmdRect = a4Rect;
+  zIndex = 2;
+  zFactor = zFactors[zIndex];
                                                           
-    [self setFrame: pageRect];
-    [self setNeedsDisplay:YES];
+  [self setFrame: pageRect];
+  [self setNeedsDisplay:YES];
 }
                                                               
 - (void)deleteSelectedObjects
@@ -347,7 +457,6 @@ float zFactors[9] = {0.25, 0.5, 1, 1.5, 2, 3, 4, 6, 8};
     if([deleted count])
     {
         [delObjects addObject: deleted];
-        // ###		[myWin setSaved: NO];
     }
     [self setNeedsDisplay: YES];
 }
@@ -697,6 +806,7 @@ float zFactors[9] = {0.25, 0.5, 1, 1.5, 2, 3, 4, 6, 8};
 
     if([objs count])
         [self moveSelectedObjects: objs startingPoint: p];
+    [[NSNotificationCenter defaultCenter] postNotificationName:@"ObjectSelectionChanged" object:self];
 }
 
 - (void)editPathAtPoint:(NSPoint)p
@@ -910,115 +1020,122 @@ float zFactors[9] = {0.25, 0.5, 1, 1.5, 2, 3, 4, 6, 8};
     }
 }
 
-- (void)inspectObject:(id)sender
+- (NSDictionary *)selectionProperties
 {
-    GRPropsEditor *propsEditor;
-    NSMutableDictionary *objProps = nil;
-    NSDictionary *newProps;
-    id obj;
-    NSNumber *num;
-    int i, count, result;
-    NSUndoManager *uMgr;
+  NSMutableDictionary *propDict;
+  int i;
+  int selectedObjects;
+  int pathObjNum;
+  int textObjNum;
+  NSNumber *num;
+  
+  if(![objects count])
+    return nil;
 
-    if(![objects count])
-        return;
-
-    for(i = 0; i < [objects count]; i++)
+  selectedObjects = 0;
+  pathObjNum = 0;
+  textObjNum = 0;
+  propDict = [NSMutableDictionary dictionaryWithCapacity: 1];
+  for(i = 0; i < [objects count]; i++)
     {
-        obj = [objects objectAtIndex: i];
-        if([[obj editor] isSelect])
+      id obj;
+      obj = [objects objectAtIndex: i];
+      
+      if([[obj editor] isSelect])
         {
-            objProps = [NSMutableDictionary dictionaryWithCapacity: 1];
-            if([obj isKindOfClass: [GRBezierPath class]] ||
-               [obj isKindOfClass: [GRCircle class]] ||
-               [obj isKindOfClass: [GRBox class]])
+          selectedObjects++;
+        
+          num = [NSNumber numberWithInt: [obj isStroked]];
+          [propDict setObject: num forKey: @"stroked"];
+          [propDict setObject: [obj strokeColor] forKey: @"strokecolor"];
+          num = [NSNumber numberWithInt: [obj isFilled]];
+          [propDict setObject: num forKey: @"filled"];
+          [propDict setObject: [obj fillColor] forKey: @"fillcolor"];
+
+          if([obj isKindOfClass: [GRPathObject class]])
             {
-                [objProps setObject: @"path" forKey: @"type"];
-                num = [NSNumber numberWithFloat: [obj flatness]];
-                [objProps setObject: num forKey: @"flatness"];
-                num = [NSNumber numberWithInt: [obj lineJoin]];
-                [objProps setObject: num forKey: @"linejoin"];
-                num = [NSNumber numberWithInt: [obj lineCap]];
-                [objProps setObject: num forKey: @"linecap"];
-                num = [NSNumber numberWithFloat: [obj miterLimit]];
-                [objProps setObject: num forKey: @"miterlimit"];
-                num = [NSNumber numberWithFloat: [obj lineWidth]];
-                [objProps setObject: num forKey: @"linewidth"];
-                num = [NSNumber numberWithInt: [obj isStroked]];
-                [objProps setObject: num forKey: @"stroked"];
-                [objProps setObject: [obj strokeColor] forKey: @"strokecolor"];
-		num = [NSNumber numberWithInt: [obj isFilled]];
-                [objProps setObject: num forKey: @"filled"];
-                [objProps setObject: [obj fillColor] forKey: @"fillcolor"];
-            } else
-            {
-                [objProps setObject: @"text" forKey: @"type"];
-                num = [NSNumber numberWithInt: [obj isStroked]];
-                [objProps setObject: num forKey: @"stroked"];
-                [objProps setObject: [obj strokeColor] forKey: @"strokecolor"];
-		num = [NSNumber numberWithInt: [obj isFilled]];
-                [objProps setObject: num forKey: @"filled"];
-                [objProps setObject: [obj fillColor] forKey: @"fillcolor"];
+              pathObjNum++;
+              num = [NSNumber numberWithFloat: [obj flatness]];
+              [propDict setObject: num forKey: @"flatness"];
+              num = [NSNumber numberWithInt: [obj lineJoin]];
+              [propDict setObject: num forKey: @"linejoin"];
+              num = [NSNumber numberWithInt: [obj lineCap]];
+              [propDict setObject: num forKey: @"linecap"];
+              num = [NSNumber numberWithFloat: [obj miterLimit]];
+              [propDict setObject: num forKey: @"miterlimit"];
+              num = [NSNumber numberWithFloat: [obj lineWidth]];
+              [propDict setObject: num forKey: @"linewidth"];
+              num = [NSNumber numberWithInt: [obj isStroked]];
             }
-            break;
-        }
-    }
-
-    if(!objProps)
-        return;
-    propsEditor = [[GRPropsEditor alloc] initWithObjectProperties: objProps];
-//    [epwin center];
-    result = [propsEditor runModal];
-    if(result == NSAlertDefaultReturn)
-    {
-        newProps = [propsEditor properties];
-        count = 0;
-        for(i = 0; i < [objects count]; i++)
-            if([[[objects objectAtIndex: i] editor] isGroupSelected])
-                count++;
-        if(count > 1)
-	{
-            result = NSRunAlertPanel(@"Alert", @"You are going to set the properties of many objects! Are you sure?", @"Ok", @"No", nil);
-            if(result != NSAlertDefaultReturn)
+          else if([obj isKindOfClass: [GRText class]])
             {
-                return;
-            }
-        }
-
-        [self saveCurrentObjectsDeep];
-
-	uMgr = [self undoManager];
-	/* save the method on the undo stack */
-	[[uMgr prepareWithInvocationTarget: self] restoreLastObjects];
-	[uMgr setActionName:@"Change Object Properties"];
-
-
-        for(i = 0; i < [objects count]; i++)
-        {
-            obj = [objects objectAtIndex: i];
-            if([[obj editor] isSelect])
-            {
-	      NSColor *newColor;
-
-                if([obj isKindOfClass: [GRBezierPath class]] || [obj isKindOfClass: [GRBox class]] || [obj isKindOfClass: [GRCircle class]])
-                {
-                    [obj setFlat: [[newProps objectForKey: @"flatness"] floatValue]];
-                    [obj setLineJoin: [[newProps objectForKey: @"linejoin"] intValue]];
-                    [obj setLineCap: [[newProps objectForKey: @"linecap"] intValue]];
-                    [obj setMiterLimit: [[newProps objectForKey: @"miterlimit"] floatValue]];
-                    [obj setLineWidth: [[newProps objectForKey: @"linewidth"] floatValue]];
-                }
-                [obj setStroked: (BOOL)[[newProps objectForKey: @"stroked"] intValue]];
-                newColor = (NSColor *)[newProps objectForKey: @"strokecolor"];
-                [obj setStrokeColor: newColor];
-                [obj setFilled: (BOOL)[[newProps objectForKey: @"filled"] intValue]];
-                newColor = (NSColor *)[newProps objectForKey: @"fillcolor"];
-                [obj setFillColor: newColor];
+              textObjNum++;
+              [propDict setObject: @"text" forKey: @"type"];
             }
         }
     }
+  
+  if(selectedObjects == 0)
+    return nil;
+  
+  if (textObjNum + pathObjNum != selectedObjects)
+    {
+      NSLog(@"Internal error: Help we lost some objects.");
+    }
+  
+  /* we check if the selection is homogeneous or not
+     and in case remove the keys that are not common among all objects */
+  if (textObjNum > 0 && pathObjNum > 0)
+    {
+      [propDict removeObjectForKey: @"flatness"];
+      [propDict removeObjectForKey: @"linejoin"];
+      [propDict removeObjectForKey: @"linecap"];
+      [propDict removeObjectForKey: @"miterlimit"];
+      [propDict removeObjectForKey: @"linewidth"];
+    }
+  
+  return propDict;
+}
 
-    [self setNeedsDisplay: YES];
+- (void)setSelectionProperties: (NSDictionary *)properties;
+{
+  NSUndoManager *uMgr;
+  id obj;
+  int i;
+  
+  uMgr = [self undoManager];
+  /* save the method on the undo stack, but stack actions */
+  if ([[uMgr undoActionName] isEqualToString: UNDO_ACTION_OBJPROPS] == NO)
+    {
+      [self saveCurrentObjectsDeep];
+      [[uMgr prepareWithInvocationTarget: self] restoreLastObjects];
+      [uMgr setActionName: UNDO_ACTION_OBJPROPS];
+    }
+  
+  for(i = 0; i < [objects count]; i++)
+    {
+      obj = [objects objectAtIndex: i];
+      if([[obj editor] isSelect])
+        {
+          NSColor *newColor;
+      
+          if([obj isKindOfClass: [GRBezierPath class]] || [obj isKindOfClass: [GRBox class]] || [obj isKindOfClass: [GRCircle class]])
+            {
+              [obj setFlat: [[properties objectForKey: @"flatness"] floatValue]];
+              [obj setLineJoin: [[properties objectForKey: @"linejoin"] intValue]];
+              [obj setLineCap: [[properties objectForKey: @"linecap"] intValue]];
+              [obj setMiterLimit: [[properties objectForKey: @"miterlimit"] floatValue]];
+              [obj setLineWidth: [[properties objectForKey: @"linewidth"] floatValue]];
+            }
+          [obj setStroked: (BOOL)[[properties objectForKey: @"stroked"] intValue]];
+          newColor = (NSColor *)[properties objectForKey: @"strokecolor"];
+          [obj setStrokeColor: newColor];
+          [obj setFilled: (BOOL)[[properties objectForKey: @"filled"] intValue]];
+          newColor = (NSColor *)[properties objectForKey: @"fillcolor"];
+          [obj setFillColor: newColor];
+        }
+    }
+  [self setNeedsDisplay: YES];
 }
 
 - (void)moveSelectedObjectsToFront:(id)sender
