@@ -2,7 +2,7 @@
  Project: Graphos
  GRDocument.m
 
- Copyright (C) 2000-2010 GNUstep Application Project
+ Copyright (C) 2000-2011 GNUstep Application Project
 
  Author: Enrico Sersale (original implementation)
  Author: Ing. Riccardo Mottola
@@ -28,12 +28,12 @@
 
 - (id)init
 {
-    [super init];
-    if (self)
-    {        
-        docView = [[GRDocView alloc] initWithFrame: NSMakeRect(0,0,0,0)];
+  self = [super init];
+  if (self)
+    {
+      documentDictionary = nil;
     }
-    return self;
+  return self;
 }
 
 - (NSString *) windowNibName
@@ -46,6 +46,7 @@
     NSPrintInfo *p;
 
     [super windowControllerDidLoadNib:aController];
+    NSLog(@"windowControllerDidLoadNib");
     if (aController == [[self windowControllers] objectAtIndex: 0])
     {
       NSScrollView *sv;
@@ -56,15 +57,17 @@
       cv = [sv contentView];
       [cv scrollToPoint: NSMakePoint(0, NSMaxY([docView bounds]))];
     }
-    
+
+    if (documentDictionary)
+      [docView createObjectsFromDictionary: documentDictionary];
     
     /* initialize the image view to the default size if possible */
     p = [self printInfo];
     if (p != nil)
-        [docView updatePrintInfo: p];
+      [docView updatePrintInfo: p];
     else
-        NSLog(@"printInfo nil!");
-    
+      NSLog(@"printInfo nil!");
+
     /* set undo levels */
     [[self undoManager] setLevelsOfUndo:1];
 
@@ -77,21 +80,28 @@
 
 - (BOOL)loadDataRepresentation:(NSData *)data ofType:(NSString *)aType
 {
-    NSString *tmp = [[[NSString alloc] initWithData: data
+  NSString *tmp = [[[NSString alloc] initWithData: data
                                            encoding: NSASCIIStringEncoding] autorelease];
 
-    if( [aType isEqualToString: @"graphos design"] && tmp != nil )
+  if( [aType isEqualToString: @"graphos design"] && tmp != nil )
     {
-        if( [tmp rangeOfString: @"<?xml"].length > 0 )
+      if( [tmp rangeOfString: @"<?xml"].length > 0 )
         {
-            tmp = [[[NSString alloc] initWithData: data
-                                         encoding: NSUTF8StringEncoding] autorelease];
+	  tmp = [[[NSString alloc] initWithData: data
+				   encoding: NSUTF8StringEncoding] autorelease];
         }
-        return [docView createObjectsFromDictionary: [tmp propertyList]];
+      documentDictionary = [[tmp propertyList] retain];
+      return (documentDictionary != nil);
     }
-    return NO;
+  return NO;
 }
 
+- (GRDocView *)docView
+{
+  return docView;
+}
+
+
 - (void)printShowingPrintPanel:(BOOL)flag
 {
     NSPrintOperation *op;
@@ -110,8 +120,8 @@
  */
 - (void)setPrintInfo:(NSPrintInfo *)printInfo
 {
-    [super setPrintInfo: printInfo];
-    [docView updatePrintInfo: printInfo];
+  [super setPrintInfo: printInfo];
+  [docView updatePrintInfo: printInfo];
 }
 
 /**
