@@ -2,7 +2,7 @@
  Project: Graphos
  GRPathObject.h
 
- Copyright (C) 2008-2010 GNUstep Application Project
+ Copyright (C) 2008-2011 GNUstep Application Project
 
  Author: Ing. Riccardo Mottola
 
@@ -40,9 +40,28 @@
     NSBezierPath *myPath;
 
     float linewidth;
+    float flatness;
+    float miterlimit;
+    int linejoin;
+    int linecap;
     GRObjectControlPoint *currentPoint;
 }
 
+- (void)setLineWidth:(float)width;
+- (float)lineWidth;
+
+- (void)setFlat:(float)flat;
+- (float)flatness;
+
+- (void)setLineJoin:(int)join;
+- (int)lineJoin;
+
+- (void)setLineCap:(int)cap;
+- (int)lineCap;
+
+- (void)setMiterLimit:(float)limit;
+- (float)miterLimit;
+
 /** sets the current selected control point */
 - (void)setCurrentPoint:(GRObjectControlPoint *)aPoint;
 
