@@ -2,7 +2,7 @@
  Project: Graphos
  GRPathObject.m
  
- Copyright (C) 2008-2010 GNUstep Application Project
+ Copyright (C) 2008-2011 GNUstep Application Project
  
  Author: Ing. Riccardo Mottola
  
@@ -57,6 +57,56 @@
     return currentPoint;
 }
 
+- (void)setLineWidth:(float)width
+{
+  linewidth = width;
+}
+
+- (float)lineWidth
+{
+  return linewidth;
+}
+
+- (void)setFlat:(float)flat
+{
+  flatness = flat;
+}
+
+- (float)flatness
+{
+  return flatness;
+}
+
+- (void)setLineJoin:(int)join
+{
+  linejoin = join;
+}
+
+- (int)lineJoin
+{
+  return linejoin;
+}
+
+- (void)setLineCap:(int)cap
+{
+  linecap = cap;
+}
+
+- (int)lineCap
+{
+  return linecap;
+}
+
+- (void)setMiterLimit:(float)limit
+{
+  miterlimit = limit;
+}
+
+- (float)miterLimit
+{
+  return miterlimit;
+}
+
 - (void)remakePath
 {
 }
