@@ -2,7 +2,7 @@
  Project: Graphos
  GRPropsEditor.h
 
- Copyright (C) 2000-2010 GNUstep Application Project
+ Copyright (C) 2000-2011 GNUstep Application Project
 
  Author: Enrico Sersale (original GDraw implementation)
  Author: Ing. Riccardo Mottola
@@ -26,6 +26,8 @@
 #import <Foundation/Foundation.h>
 #import <AppKit/AppKit.h>
 
+@class GRDocView;
+
 /**
  * Object properties editor
  */
@@ -34,8 +36,6 @@
 @interface GRPropsEditor : NSObject
 {
   IBOutlet NSPanel *propsPanel;
-  
-  int result;
 
   IBOutlet NSButton *stkButt;
   IBOutlet NSButton *fllButt;
@@ -50,21 +50,30 @@
   IBOutlet NSColorWell *strokeColorWell;
   IBOutlet NSColorWell *fillColorWell;
 
-  IBOutlet NSButton *cancelButt;
-  IBOutlet NSButton *okButt;
-
-    BOOL ispath;
-    float flatness, miterlimit, linewidth;
-    int linejoin, linecap;
-    BOOL stroked;
+  BOOL ispath;
+  float flatness, miterlimit, linewidth;
+  int linejoin, linecap;
+  BOOL stroked;
   NSColor *strokeColor;
-    BOOL filled;
+  BOOL filled;
   NSColor *fillColor;
+  
+  GRDocView *docView;
 }
 
-- (id)initWithObjectProperties:(NSDictionary *)objprops;
+- (void)setControlsEnabled:(BOOL)state;
 
-- (int)runModal;
+/** reads the selection properties from the current view */
+- (void)readProperties;
+
+/** sets the view which contains the objects.
+  The view needs to needs to be set so that the selection properties
+  can be read or applied. */
+- (void)setDocView: (GRDocView *)view;
+
+- (void)makeKeyAndOrderFront:(id)sender;
+
+- (void)selectionChanged: (NSNotification *)notif;
 
 - (void)controlTextDidEndEditing:(NSNotification *)aNotification;
 
@@ -76,7 +85,7 @@
 
 - (IBAction)stkButtPressed:(id)sender;
 
-- (IBAction)okCancelPressed:(id)sender;
+- (IBAction)valuesChanged:(id)sender;
 
 - (NSDictionary *)properties;
 
