@@ -2,7 +2,7 @@
  Project: Graphos
  GRText.h
 
- Copyright (C) 2000-2010 GNUstep Application Project
+ Copyright (C) 2000-2011 GNUstep Application Project
 
  Author: Enrico Sersale (original GDraw implementation)
  Author: Ing. Riccardo Mottola
@@ -46,16 +46,15 @@
 
 - (id)initInView:(GRDocView *)aView
          atPoint:(NSPoint)p
-                    zoomFactor:(float)zf
-                    openEditor:(BOOL)openedit;
+      zoomFactor:(float)zf
+  withProperties:(NSDictionary *)properties
+      openEditor:(BOOL)openedit;
 
 - (id)initFromData:(NSDictionary *)description
             inView:(GRDocView *)aView
         zoomFactor:(float)zf;
 
 
-- (NSString *)psDescription;
-
 - (NSString *)fontName;
 
 - (void)setString:(NSString *)aString attributes:(NSDictionary *)attrs;
