@@ -2,7 +2,7 @@
  Project: Graphos
  GRText.m
 
- Copyright (C) 2000-2010 GNUstep Application Project
+ Copyright (C) 2000-2011 GNUstep Application Project
 
  Author: Enrico Sersale (original GDraw implementation)
  Author: Ing. Riccardo Mottola
@@ -36,40 +36,60 @@
 - (id)initInView:(GRDocView *)aView
          atPoint:(NSPoint)p
       zoomFactor:(float)zf
+  withProperties:(NSDictionary *) properties
       openEditor:(BOOL)openedit
 {
-    int result;
+  int result;
 
-    self = [super init];
-    if(self)
+  self = [super init];
+  if(self)
     {
-        docView = aView;
-        zmFactor = zf;
-        pos = NSMakePoint(p.x / zf, p.y / zf);
-        rotation = 0;
-        scalex = 1;
-        scaley = 1;
-        stroked = YES;
-        filled = NO;
-        visible = YES;
-        locked = NO;
-        strokeColor = [[NSColor blackColor] retain];
-        fillColor = [[NSColor whiteColor] retain];
-        ASSIGN(str, @"");
+      docView = aView;
+      zmFactor = zf;
+      pos = NSMakePoint(p.x / zf, p.y / zf);
+      rotation = 0;
+      scalex = 1;
+      scaley = 1;
+      stroked = YES;
+      filled = NO;
+      visible = YES;
+      locked = NO;
+      strokeColor = [[NSColor blackColor] retain];
+      fillColor = [[NSColor whiteColor] retain];
+      ASSIGN(str, @"");
 
-        editor = [[GRTextEditor alloc] initEditor:(GRText*)self];
-        if(openedit)
-        {
-            [(GRTextEditor *)editor setPoint: pos
-                  withString: nil
-                  attributes: nil];
-            result = [(GRTextEditor *)editor runModal];
-            if(result == NSAlertDefaultReturn)
-                [self setString: [[(GRTextEditor *)editor editorView] textString]
-                     attributes: [[(GRTextEditor *)editor editorView] textAttributes]];
+      if (properties != nil)
+	{
+	  NSColor *newColor;
+	  NSString *val;
+	  
+	  val = [properties objectForKey: @"stroked"];
+	  if (val != nil)
+	    [self setStroked: (BOOL)[val intValue]];
+	  newColor = (NSColor *)[properties objectForKey: @"strokecolor"];
+	  if (newColor != nil)
+	    [self setStrokeColor: newColor];
+	  
+	  val = [properties objectForKey: @"filled"];
+	  if (val != nil)
+	    [self setFilled: (BOOL)[val intValue]];
+	  newColor = (NSColor *)[properties objectForKey: @"fillcolor"];
+	  if (newColor != nil)
+	    [self setFillColor: newColor];
+	}
+      editor = [[GRTextEditor alloc] initEditor:(GRText*)self];
+      if(openedit)
+	{
+	  [(GRTextEditor *)editor setPoint: pos
+				withString: nil
+				attributes: nil];
+	  result = [(GRTextEditor *)editor runModal];
+	  if(result == NSAlertDefaultReturn)
+	    [self setString: [[(GRTextEditor *)editor editorView] textString]
+		 attributes: [[(GRTextEditor *)editor editorView] textAttributes]];
         }
     }
-    return self;
+  return self;
 }
 
 - (id)initFromData:(NSDictionary *)description
@@ -238,26 +258,6 @@
     return dict;
 }
 
-- (NSString *)psDescription
-{
-    NSString *pss;
-
-    if(!visible)
-        return nil;
-
-    pss = [NSString stringWithFormat:
-        @"\n/%@ %.3f sf\nn\n%.3f %.3f m\n(%@)show\n",
-        [font fontName], fsize, pos.x, pos.y, str];
-    if(stroked)
-        pss = [pss stringByAppendingFormat: @"%.3f %.3f %.3f %.3f k\nstroke\n",
-            strokeColor[0], strokeColor[1], strokeColor[2], strokeColor[3]];
-    if(filled)
-        pss = [pss stringByAppendingFormat: @"%.3f %.3f %.3f %.3f k\nfill\n",
-            fillColor[0], fillColor[1], fillColor[2], fillColor[3]];
-
-    return pss;
-}
-
 - (NSString *)fontName
 {
     return [font fontName];
