@@ -2,7 +2,7 @@
  Project: Graphos
  Graphos.h
 
- Copyright (C) 2000-2008 GNUstep Application Project
+ Copyright (C) 2000-2012 GNUstep Application Project
 
  Author: Enrico Sersale (original implementation)
  Author: Ing. Riccardo Mottola
@@ -24,7 +24,12 @@
 
 #import <Foundation/Foundation.h>
 #import <AppKit/AppKit.h>
+
 #import "GRTools.h"
+#import "GRPropsEditor.h"
+
+/* change this if the new file format becomes incompatible */
+#define FILE_FORMAT_VERSION 0.3
 
 /**
  * tool types structure
@@ -54,8 +59,13 @@ typedef enum
 {
     GRToolsWindow *tools;
     ToolType tooltype;
+    GRPropsEditor *objectInspector;
 }
 
+- (IBAction)showObjectInspector: (id)sender;
+
+- (GRPropsEditor *)objectInspector;
+
 - (void)setToolType:(ToolType)type;
 
 - (ToolType)currentToolType;
